/****************************************************************************
** Meta object code from reading C++ file 'mapasker.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kgeography-17.04.3/src/mapasker.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mapasker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_mapAsker_t {
    QByteArrayData data[11];
    char stringdata0[89];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_mapAsker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_mapAsker_t qt_meta_stringdata_mapAsker = {
    {
QT_MOC_LITERAL(0, 0, 8), // "mapAsker"
QT_MOC_LITERAL(1, 9, 11), // "setMovement"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 1), // "b"
QT_MOC_LITERAL(4, 24, 7), // "setZoom"
QT_MOC_LITERAL(5, 32, 15), // "setOriginalZoom"
QT_MOC_LITERAL(6, 48, 16), // "setAutomaticZoom"
QT_MOC_LITERAL(7, 65, 14), // "handleMapClick"
QT_MOC_LITERAL(8, 80, 4), // "QRgb"
QT_MOC_LITERAL(9, 85, 1), // "c"
QT_MOC_LITERAL(10, 87, 1) // "p"

    },
    "mapAsker\0setMovement\0\0b\0setZoom\0"
    "setOriginalZoom\0setAutomaticZoom\0"
    "handleMapClick\0QRgb\0c\0p"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_mapAsker[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x0a /* Public */,
       4,    1,   42,    2, 0x0a /* Public */,
       5,    0,   45,    2, 0x0a /* Public */,
       6,    1,   46,    2, 0x0a /* Public */,
       7,    2,   49,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 8, QMetaType::QPoint,    9,   10,

       0        // eod
};

void mapAsker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        mapAsker *_t = static_cast<mapAsker *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setMovement((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->setZoom((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setOriginalZoom(); break;
        case 3: _t->setAutomaticZoom((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->handleMapClick((*reinterpret_cast< QRgb(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject mapAsker::staticMetaObject = {
    { &askWidget::staticMetaObject, qt_meta_stringdata_mapAsker.data,
      qt_meta_data_mapAsker,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *mapAsker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *mapAsker::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_mapAsker.stringdata0))
        return static_cast<void*>(const_cast< mapAsker*>(this));
    return askWidget::qt_metacast(_clname);
}

int mapAsker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = askWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
