/****************************************************************************
** Meta object code from reading C++ file 'askwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kgeography-17.04.3/src/askwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'askwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_askWidget_t {
    QByteArrayData data[13];
    char stringdata0[190];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_askWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_askWidget_t qt_meta_stringdata_askWidget = {
    {
QT_MOC_LITERAL(0, 0, 9), // "askWidget"
QT_MOC_LITERAL(1, 10, 20), // "setMoveActionChecked"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 1), // "b"
QT_MOC_LITERAL(4, 34, 29), // "setAutomaticZoomActionChecked"
QT_MOC_LITERAL(5, 64, 20), // "setZoomActionChecked"
QT_MOC_LITERAL(6, 85, 20), // "setMoveActionEnabled"
QT_MOC_LITERAL(7, 106, 14), // "questionsEnded"
QT_MOC_LITERAL(8, 121, 11), // "setMovement"
QT_MOC_LITERAL(9, 133, 7), // "setZoom"
QT_MOC_LITERAL(10, 141, 15), // "setOriginalZoom"
QT_MOC_LITERAL(11, 157, 16), // "setAutomaticZoom"
QT_MOC_LITERAL(12, 174, 15) // "resetLabelColor"

    },
    "askWidget\0setMoveActionChecked\0\0b\0"
    "setAutomaticZoomActionChecked\0"
    "setZoomActionChecked\0setMoveActionEnabled\0"
    "questionsEnded\0setMovement\0setZoom\0"
    "setOriginalZoom\0setAutomaticZoom\0"
    "resetLabelColor"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_askWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    1,   67,    2, 0x06 /* Public */,
       5,    1,   70,    2, 0x06 /* Public */,
       6,    1,   73,    2, 0x06 /* Public */,
       7,    0,   76,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   77,    2, 0x0a /* Public */,
       9,    1,   80,    2, 0x0a /* Public */,
      10,    0,   83,    2, 0x0a /* Public */,
      11,    1,   84,    2, 0x0a /* Public */,
      12,    0,   87,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,

       0        // eod
};

void askWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        askWidget *_t = static_cast<askWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setMoveActionChecked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->setAutomaticZoomActionChecked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setZoomActionChecked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->setMoveActionEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->questionsEnded(); break;
        case 5: _t->setMovement((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->setZoom((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->setOriginalZoom(); break;
        case 8: _t->setAutomaticZoom((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->resetLabelColor(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (askWidget::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&askWidget::setMoveActionChecked)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (askWidget::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&askWidget::setAutomaticZoomActionChecked)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (askWidget::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&askWidget::setZoomActionChecked)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (askWidget::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&askWidget::setMoveActionEnabled)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (askWidget::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&askWidget::questionsEnded)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject askWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_askWidget.data,
      qt_meta_data_askWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *askWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *askWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_askWidget.stringdata0))
        return static_cast<void*>(const_cast< askWidget*>(this));
    return QWidget::qt_metacast(_clname);
}

int askWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void askWidget::setMoveActionChecked(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void askWidget::setAutomaticZoomActionChecked(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void askWidget::setZoomActionChecked(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void askWidget::setMoveActionEnabled(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void askWidget::questionsEnded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
