/****************************************************************************
** Meta object code from reading C++ file 'mapwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kgeography-17.04.3/src/mapwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mapwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_mapWidget_t {
    QByteArrayData data[10];
    char stringdata0[123];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_mapWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_mapWidget_t qt_meta_stringdata_mapWidget = {
    {
QT_MOC_LITERAL(0, 0, 9), // "mapWidget"
QT_MOC_LITERAL(1, 10, 20), // "setMoveActionChecked"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 1), // "b"
QT_MOC_LITERAL(4, 34, 20), // "setZoomActionChecked"
QT_MOC_LITERAL(5, 55, 20), // "setMoveActionEnabled"
QT_MOC_LITERAL(6, 76, 7), // "clicked"
QT_MOC_LITERAL(7, 84, 4), // "QRgb"
QT_MOC_LITERAL(8, 89, 16), // "setOriginalImage"
QT_MOC_LITERAL(9, 106, 16) // "setAutomaticZoom"

    },
    "mapWidget\0setMoveActionChecked\0\0b\0"
    "setZoomActionChecked\0setMoveActionEnabled\0"
    "clicked\0QRgb\0setOriginalImage\0"
    "setAutomaticZoom"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_mapWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       4,    1,   47,    2, 0x06 /* Public */,
       5,    1,   50,    2, 0x06 /* Public */,
       6,    2,   53,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,   58,    2, 0x0a /* Public */,
       9,    1,   59,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 7, QMetaType::QPoint,    2,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    3,

       0        // eod
};

void mapWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        mapWidget *_t = static_cast<mapWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setMoveActionChecked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->setZoomActionChecked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setMoveActionEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->clicked((*reinterpret_cast< QRgb(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 4: _t->setOriginalImage(); break;
        case 5: _t->setAutomaticZoom((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (mapWidget::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&mapWidget::setMoveActionChecked)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (mapWidget::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&mapWidget::setZoomActionChecked)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (mapWidget::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&mapWidget::setMoveActionEnabled)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (mapWidget::*_t)(QRgb , const QPoint & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&mapWidget::clicked)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject mapWidget::staticMetaObject = {
    { &QGraphicsView::staticMetaObject, qt_meta_stringdata_mapWidget.data,
      qt_meta_data_mapWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *mapWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *mapWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_mapWidget.stringdata0))
        return static_cast<void*>(const_cast< mapWidget*>(this));
    return QGraphicsView::qt_metacast(_clname);
}

int mapWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void mapWidget::setMoveActionChecked(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void mapWidget::setZoomActionChecked(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void mapWidget::setMoveActionEnabled(bool _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void mapWidget::clicked(QRgb _t1, const QPoint & _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_END_MOC_NAMESPACE
