/****************************************************************************
** Meta object code from reading C++ file 'kgeography.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kgeography-17.04.3/src/kgeography.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kgeography.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_kgeography_t {
    QByteArrayData data[19];
    char stringdata0[260];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_kgeography_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_kgeography_t qt_meta_stringdata_kgeography = {
    {
QT_MOC_LITERAL(0, 0, 10), // "kgeography"
QT_MOC_LITERAL(1, 11, 7), // "openMap"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 7), // "consult"
QT_MOC_LITERAL(4, 28, 19), // "askCapitalDivisions"
QT_MOC_LITERAL(5, 48, 19), // "askDivisionCapitals"
QT_MOC_LITERAL(6, 68, 6), // "askMap"
QT_MOC_LITERAL(7, 75, 11), // "askPlaceMap"
QT_MOC_LITERAL(8, 87, 16), // "askFlagDivisions"
QT_MOC_LITERAL(9, 104, 16), // "askDivisionFlags"
QT_MOC_LITERAL(10, 121, 10), // "disclaimer"
QT_MOC_LITERAL(11, 132, 13), // "showMapAuthor"
QT_MOC_LITERAL(12, 146, 16), // "resizeMainWindow"
QT_MOC_LITERAL(13, 163, 14), // "questionsEnded"
QT_MOC_LITERAL(14, 178, 16), // "setAutomaticZoom"
QT_MOC_LITERAL(15, 195, 1), // "b"
QT_MOC_LITERAL(16, 197, 20), // "setMoveActionEnabled"
QT_MOC_LITERAL(17, 218, 21), // "showPreferencesDialog"
QT_MOC_LITERAL(18, 240, 19) // "updateConfiguration"

    },
    "kgeography\0openMap\0\0consult\0"
    "askCapitalDivisions\0askDivisionCapitals\0"
    "askMap\0askPlaceMap\0askFlagDivisions\0"
    "askDivisionFlags\0disclaimer\0showMapAuthor\0"
    "resizeMainWindow\0questionsEnded\0"
    "setAutomaticZoom\0b\0setMoveActionEnabled\0"
    "showPreferencesDialog\0updateConfiguration"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_kgeography[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x08 /* Private */,
       3,    0,   95,    2, 0x08 /* Private */,
       4,    0,   96,    2, 0x08 /* Private */,
       5,    0,   97,    2, 0x08 /* Private */,
       6,    0,   98,    2, 0x08 /* Private */,
       7,    0,   99,    2, 0x08 /* Private */,
       8,    0,  100,    2, 0x08 /* Private */,
       9,    0,  101,    2, 0x08 /* Private */,
      10,    0,  102,    2, 0x08 /* Private */,
      11,    0,  103,    2, 0x08 /* Private */,
      12,    0,  104,    2, 0x08 /* Private */,
      13,    0,  105,    2, 0x08 /* Private */,
      14,    1,  106,    2, 0x08 /* Private */,
      16,    1,  109,    2, 0x08 /* Private */,
      17,    0,  112,    2, 0x08 /* Private */,
      18,    0,  113,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   15,
    QMetaType::Void, QMetaType::Bool,   15,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void kgeography::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        kgeography *_t = static_cast<kgeography *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->openMap(); break;
        case 1: _t->consult(); break;
        case 2: _t->askCapitalDivisions(); break;
        case 3: _t->askDivisionCapitals(); break;
        case 4: _t->askMap(); break;
        case 5: _t->askPlaceMap(); break;
        case 6: _t->askFlagDivisions(); break;
        case 7: _t->askDivisionFlags(); break;
        case 8: _t->disclaimer(); break;
        case 9: _t->showMapAuthor(); break;
        case 10: _t->resizeMainWindow(); break;
        case 11: _t->questionsEnded(); break;
        case 12: _t->setAutomaticZoom((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->setMoveActionEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->showPreferencesDialog(); break;
        case 15: _t->updateConfiguration(); break;
        default: ;
        }
    }
}

const QMetaObject kgeography::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_kgeography.data,
      qt_meta_data_kgeography,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *kgeography::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *kgeography::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_kgeography.stringdata0))
        return static_cast<void*>(const_cast< kgeography*>(this));
    return KXmlGuiWindow::qt_metacast(_clname);
}

int kgeography::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
