// This file is generated by kconfig_compiler_kf5 from kgeography.kcfg.
// All changes you do to this file will be lost.

#include "settings.h"

#include <qglobal.h>
#include <QtCore/QFile>

class kgeographySettingsHelper
{
  public:
    kgeographySettingsHelper() : q(nullptr) {}
    ~kgeographySettingsHelper() { delete q; }
    kgeographySettings *q;
};
Q_GLOBAL_STATIC(kgeographySettingsHelper, s_globalkgeographySettings)
kgeographySettings *kgeographySettings::self()
{
  if (!s_globalkgeographySettings()->q) {
    new kgeographySettings;
    s_globalkgeographySettings()->q->read();
  }

  return s_globalkgeographySettings()->q;
}

kgeographySettings::kgeographySettings(  )
  : KConfigSkeleton( QStringLiteral( "kgeographyrc" ) )
{
  Q_ASSERT(!s_globalkgeographySettings()->q);
  s_globalkgeographySettings()->q = this;
  setCurrentGroup( QStringLiteral( "general" ) );

  KConfigSkeleton::ItemString  *itemLastMap;
  itemLastMap = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "lastMap" ), mLastMap );
  addItem( itemLastMap, QStringLiteral( "lastMap" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesquestionPlacingScheme;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TopLeft");
    valuesquestionPlacingScheme.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Top");
    valuesquestionPlacingScheme.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("TopRight");
    valuesquestionPlacingScheme.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Left");
    valuesquestionPlacingScheme.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Center");
    valuesquestionPlacingScheme.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Right");
    valuesquestionPlacingScheme.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BottomLeft");
    valuesquestionPlacingScheme.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Bottom");
    valuesquestionPlacingScheme.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("BottomRight");
    valuesquestionPlacingScheme.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemQuestionPlacingScheme;
  itemQuestionPlacingScheme = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "questionPlacingScheme" ), mQuestionPlacingScheme, valuesquestionPlacingScheme, EnumQuestionPlacingScheme::TopLeft );
  addItem( itemQuestionPlacingScheme, QStringLiteral( "questionPlacingScheme" ) );
  KConfigSkeleton::ItemBool  *itemWaitsForValidation;
  itemWaitsForValidation = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "waitsForValidation" ), mWaitsForValidation, true );
  addItem( itemWaitsForValidation, QStringLiteral( "waitsForValidation" ) );
  KConfigSkeleton::ItemBool  *itemFocusFollowsMouse;
  itemFocusFollowsMouse = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "focusFollowsMouse" ), mFocusFollowsMouse, false );
  addItem( itemFocusFollowsMouse, QStringLiteral( "focusFollowsMouse" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuescolorDisguise;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Nothing");
    valuescolorDisguise.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Scramble");
    valuescolorDisguise.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemColorDisguise;
  itemColorDisguise = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "colorDisguise" ), mColorDisguise, valuescolorDisguise, EnumColorDisguise::Nothing );
  addItem( itemColorDisguise, QStringLiteral( "colorDisguise" ) );
}

kgeographySettings::~kgeographySettings()
{
  s_globalkgeographySettings()->q = nullptr;
}

