#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'kgeographyoptions.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KGEOGRAPHYOPTIONS_H
#define UI_KGEOGRAPHYOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Options
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *kcfg_questionPlacingScheme;
    QGridLayout *gridLayout;
    QRadioButton *topleftRadio;
    QRadioButton *topRadio;
    QRadioButton *toprightRadio;
    QRadioButton *leftRadio;
    QRadioButton *centerRadio;
    QRadioButton *rightRadio;
    QRadioButton *bottomleftRadio;
    QRadioButton *bottomRadio;
    QRadioButton *bottomrightRadio;
    QCheckBox *kcfg_waitsForValidation;
    QCheckBox *kcfg_focusFollowsMouse;
    QGroupBox *kcfg_colorDisguise;
    QGridLayout *gridLayout_2;
    QRadioButton *noColorDisguiseRadio;
    QRadioButton *scrambleColorDisguiseRadio;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Options)
    {
        if (Options->objectName().isEmpty())
            Options->setObjectName(QStringLiteral("Options"));
        Options->resize(684, 594);
        verticalLayout = new QVBoxLayout(Options);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        kcfg_questionPlacingScheme = new QGroupBox(Options);
        kcfg_questionPlacingScheme->setObjectName(QStringLiteral("kcfg_questionPlacingScheme"));
        gridLayout = new QGridLayout(kcfg_questionPlacingScheme);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        topleftRadio = new QRadioButton(kcfg_questionPlacingScheme);
        topleftRadio->setObjectName(QStringLiteral("topleftRadio"));

        gridLayout->addWidget(topleftRadio, 0, 0, 1, 1);

        topRadio = new QRadioButton(kcfg_questionPlacingScheme);
        topRadio->setObjectName(QStringLiteral("topRadio"));

        gridLayout->addWidget(topRadio, 0, 1, 1, 1);

        toprightRadio = new QRadioButton(kcfg_questionPlacingScheme);
        toprightRadio->setObjectName(QStringLiteral("toprightRadio"));

        gridLayout->addWidget(toprightRadio, 0, 2, 1, 1);

        leftRadio = new QRadioButton(kcfg_questionPlacingScheme);
        leftRadio->setObjectName(QStringLiteral("leftRadio"));

        gridLayout->addWidget(leftRadio, 1, 0, 1, 1);

        centerRadio = new QRadioButton(kcfg_questionPlacingScheme);
        centerRadio->setObjectName(QStringLiteral("centerRadio"));

        gridLayout->addWidget(centerRadio, 1, 1, 1, 1);

        rightRadio = new QRadioButton(kcfg_questionPlacingScheme);
        rightRadio->setObjectName(QStringLiteral("rightRadio"));

        gridLayout->addWidget(rightRadio, 1, 2, 1, 1);

        bottomleftRadio = new QRadioButton(kcfg_questionPlacingScheme);
        bottomleftRadio->setObjectName(QStringLiteral("bottomleftRadio"));

        gridLayout->addWidget(bottomleftRadio, 2, 0, 1, 1);

        bottomRadio = new QRadioButton(kcfg_questionPlacingScheme);
        bottomRadio->setObjectName(QStringLiteral("bottomRadio"));

        gridLayout->addWidget(bottomRadio, 2, 1, 1, 1);

        bottomrightRadio = new QRadioButton(kcfg_questionPlacingScheme);
        bottomrightRadio->setObjectName(QStringLiteral("bottomrightRadio"));

        gridLayout->addWidget(bottomrightRadio, 2, 2, 1, 1);


        verticalLayout->addWidget(kcfg_questionPlacingScheme);

        kcfg_waitsForValidation = new QCheckBox(Options);
        kcfg_waitsForValidation->setObjectName(QStringLiteral("kcfg_waitsForValidation"));

        verticalLayout->addWidget(kcfg_waitsForValidation);

        kcfg_focusFollowsMouse = new QCheckBox(Options);
        kcfg_focusFollowsMouse->setObjectName(QStringLiteral("kcfg_focusFollowsMouse"));

        verticalLayout->addWidget(kcfg_focusFollowsMouse);

        kcfg_colorDisguise = new QGroupBox(Options);
        kcfg_colorDisguise->setObjectName(QStringLiteral("kcfg_colorDisguise"));
        kcfg_colorDisguise->setEnabled(true);
        gridLayout_2 = new QGridLayout(kcfg_colorDisguise);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        noColorDisguiseRadio = new QRadioButton(kcfg_colorDisguise);
        noColorDisguiseRadio->setObjectName(QStringLiteral("noColorDisguiseRadio"));

        gridLayout_2->addWidget(noColorDisguiseRadio, 0, 0, 1, 1);

        scrambleColorDisguiseRadio = new QRadioButton(kcfg_colorDisguise);
        scrambleColorDisguiseRadio->setObjectName(QStringLiteral("scrambleColorDisguiseRadio"));

        gridLayout_2->addWidget(scrambleColorDisguiseRadio, 0, 1, 1, 1);


        verticalLayout->addWidget(kcfg_colorDisguise);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(Options);

        QMetaObject::connectSlotsByName(Options);
    } // setupUi

    void retranslateUi(QWidget *Options)
    {
        kcfg_questionPlacingScheme->setTitle(tr2i18n("&Question Alignment", 0));
        topleftRadio->setText(tr2i18n("Top-l&eft", 0));
        topRadio->setText(tr2i18n("&Top", 0));
        toprightRadio->setText(tr2i18n("Top-r&ight", 0));
        leftRadio->setText(tr2i18n("&Left", 0));
        centerRadio->setText(tr2i18n("&Center", 0));
        rightRadio->setText(tr2i18n("&Right", 0));
        bottomleftRadio->setText(tr2i18n("Bottom-le&ft", 0));
        bottomRadio->setText(tr2i18n("&Bottom", 0));
        bottomrightRadio->setText(tr2i18n("Bottom-ri&ght", 0));
#ifndef UI_QT_NO_TOOLTIP
        kcfg_waitsForValidation->setToolTip(tr2i18n("Whether the user will have to click \"Accept\" after choosing an answer or not", 0));
#endif // QT_NO_TOOLTIP
        kcfg_waitsForValidation->setText(tr2i18n("&Wait for validation", 0));
#ifndef UI_QT_NO_TOOLTIP
        kcfg_focusFollowsMouse->setToolTip(tr2i18n("Whether pressing space will trigger button under mouse or not", 0));
#endif // QT_NO_TOOLTIP
        kcfg_focusFollowsMouse->setText(tr2i18n("&Focus follows mouse", 0));
#ifndef UI_QT_NO_TOOLTIP
        kcfg_colorDisguise->setToolTip(tr2i18n("Choose if you want to keep current divisions colors or have random colors.", 0));
#endif // QT_NO_TOOLTIP
        kcfg_colorDisguise->setTitle(tr2i18n("Map divisions colors", 0));
        noColorDisguiseRadio->setText(tr2i18n("Always the same", 0));
        scrambleColorDisguiseRadio->setText(tr2i18n("Use random colors", 0));
        Q_UNUSED(Options);
    } // retranslateUi

};

namespace Ui {
    class Options: public Ui_Options {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KGEOGRAPHYOPTIONS_H

